@@ -23,6 +23,11 @@ def get_user(puid, provider=None, session=None):
     return q.one()
 
 
+@with_db
+def get_user_by_id(id, session=None):
+    return session.query(User).get(id)
+
+
 @with_db
 def get_provider(name, session=None):
     q = session.query(Provider).filter_by(name=name)
